part of leadlinkopenapi;

// 帐号管理相关接口
class APIAccountManager {
  
  // 注册 - 请求发送短信验证码
  static requestSMSCode(String mobile,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    try {
       await LCSMSClient.requestSMSCode(mobile);
       if (onSucc != null) onSucc(APITip.smsSendSucc);
    } on LCException catch (_) {
       if (onFail != null) onFail(APITip.smsSendFail);
    }

  }

  // 注册 - 使用「验证码」验证用户手机号码
  static verifyMobilePhone(String mobile, String smsCode,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    if (APIUtil.isNullOrEmpty(smsCode)) {
      if (onFail != null) onFail(APITip.emptySMSCode);
      return;
    }

    if (smsCode.length != 6) {
      if (onFail != null) onFail(APITip.illegalSMSCode);
      return;
    }

    try {
       await LCSMSClient.verifyMobilePhone(mobile,smsCode);
       if (onSucc != null) onSucc(APITip.smsVeriSucc);
    } on LCException catch (_) {
       if (onFail != null) onFail(APITip.smsVeriFail);
    }

  }

  // 重置密码 - 请求发送手机短信验证码重置用户密码
  static requestPasswordResetBySmsCode(String mobile,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    try {
      await LCUser.requestPasswordRestBySmsCode(mobile);
      if (onSucc != null) onSucc(APITip.smsSendSucc);
    } on LCException catch (_) {
      if (onFail != null) onFail(APITip.smsSendFail);
    }
  }

  // 重置密码 - 验证手机短信验证码并重置密码
  static resetPasswordBySmsCode(String mobile, String smsCode, String password,{Function(String) onSucc, Function(String) onFail}) async {
    
    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    if (APIUtil.isNullOrEmpty(smsCode)) {
      if (onFail != null) onFail(APITip.emptySMSCode);
      return;
    }

    if (smsCode.length != 6) {
      if (onFail != null) onFail(APITip.illegalSMSCode);
      return;
    }

    if (APIUtil.isNullOrEmpty(password)) {
      if (onFail != null) onFail(APITip.emptyPassword);
      return;
    }

    if (password.length < 6 || password.length > 20) {
      if (onFail != null) onFail(APITip.illegalPassword);
      return;
    }

     try {
        await LCUser.resetPasswordBySmsCode(mobile, smsCode, password);
        if (onSucc != null) onSucc(APITip.pasdRestSucc);
     } on LCException catch (_) {
        if (onFail != null) onFail(APITip.pasdRestFail);
    }

  }



  // 通过手机号 + 密码注册
  static signUp(String mobile, String password,{String nickName,Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    if (APIUtil.isNullOrEmpty(password)) {
      if (onFail != null) onFail(APITip.emptyPassword);
      return;
    }

    if (password.length < 6 || password.length > 20) {
      if (onFail != null) onFail(APITip.illegalPassword);
      return;
    }

    try {

      LCUser user       = LCUser();
      user.username     = mobile;
      user.password     = password;
      user.mobile       = mobile;
      user['isAdmin']   = 0;
      user['isDisable'] = 0;
      user['nickName']  = nickName ?? '';

      await user.signUp();

      if (onSucc != null) onSucc(APITip.signupSucc);

    } on LCException catch (e) {
      var emsg = APITip.signupFail;
      if (e.code == 214) emsg = APITip.signupHave;
      if (onFail != null) onFail(emsg);
    }
  }

  // 普通用户登录
  static login(String mobile, String password,{bool isAdminLogin,Function(String msg,int userId) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();

    if (isReachable == false) {
      if (onFail != null) onFail(APITip.noConnect);
      return;
    }

    if (APIUtil.isNullOrEmpty(mobile)) {
      if (onFail != null) onFail(APITip.emptyPhone);
      return;
    }

    if (mobile.length != 11) {
      if (onFail != null) onFail(APITip.illegalPhone);
      return;
    }

    if (APIUtil.isNullOrEmpty(password)) {
      if (onFail != null) onFail(APITip.emptyPassword);
      return;
    }

    if (password.length < 6 || password.length > 20) {
      if (onFail != null) onFail(APITip.illegalPassword);
      return;
    }

    try {

      LCUser user = await LCUser.loginByMobilePhoneNumber(mobile, password);

      bool isActive   = user['isDisable'] == 0 ? true : false;
      int userId     = user['userId'] ?? 0;

      // 帐号禁用判断
      if(!isActive) {
        if (onFail != null) onFail(APITip.loginDisable);
        return;
      }
      // 用户id不存在
      if(userId == 0) {
        if (onFail != null) onFail(APITip.login404);
        return;
      }
  
      // 普通登录
      bool isEnterWithAdmin = isAdminLogin ?? false;
      if(!isEnterWithAdmin) {

        SharedPreferences prefs = await SharedPreferences.getInstance();
        await prefs.setString(APITip.spKeyMobile, mobile);
        await prefs.setString(APITip.spKeyPassword, password);
        await prefs.setInt(APITip.spKeyUserId, userId);
        if (onSucc != null) onSucc(APITip.loginSucc,userId);
        return;
      }

      // 具有后台权限的管理员登录
      bool isAdmin  = user['isAdmin'] == 1 ? true : false;
      if(!isAdmin) {
        if (onFail != null) onFail(APITip.loginNoPermission);
        return;
      }

      SharedPreferences prefs = await SharedPreferences.getInstance();
      await prefs.setString(APITip.spKeyMobile, mobile);
      await prefs.setString(APITip.spKeyPassword, password);
      await prefs.setInt(APITip.spKeyUserId, userId);
      if (onSucc != null) onSucc(APITip.loginSucc,userId);

    } on LCException catch (e) {
      final code = e.code;
      var emsg = APITip.loginFail;
      if (code == 210) {
        emsg = APITip.loginWrong;
      } else if (code == 211) {
        emsg = APITip.login404;
      } else if (code == 219) {
        emsg = APITip.loginLimit;
      } else {
        emsg =  APITip.loginFail;
      }
      if (onFail != null) onFail(emsg);
    }
  }
}