part of leadlinkopenapi;

// 包管理更新
class PackageUpdate extends ParseObject implements ParseCloneable {

  PackageUpdate() : super(kTableName);
  PackageUpdate.clone() : this();
  
  @override clone(Map map) => PackageUpdate.clone().fromJson(map);

  static const String kTableName = 'PackageUpdate';
  // ID
  int get id => this['packageUpdateId'] ?? 0 ;
  // 标题
  String get title => this['title'] ?? '';
  // 内容
  String get message => this['message'] ?? '';
  // 下载地址
  String get url => this['url'] ?? '';
  // 下载地址
  String get platform => this['platform'] ?? '';
  // 最低版本号
  int get version => this['version'] ?? 9999;
  // 强制更新
  bool get isForce => this['isForce'] ?? false;

}

// 用户类型
class UserType extends ParseObject implements ParseCloneable {

  UserType() : super(kTableName);
  UserType.clone() : this();
  
  @override clone(Map map) => UserType.clone().fromJson(map);

  static const String kTableName = 'UserType';
  // ID
  int get id => this['userTypeId'] ?? 0 ;
  // 昵称
  String get name => this['name'] ?? '';
  // 备注
  String get remark => this['remark'] ?? '';
  // 激活
  bool get isActive => this['isActive'] ?? false;

}

// 用户
class Users extends ParseObject implements ParseCloneable {

  Users() : super(kTableName);
  Users.clone() : this();
  
  @override clone(Map map) => Users.clone().fromJson(map);

  static const String kTableName = 'Users';
  // ID
  int get id => this['userId'] ?? 0 ;
  // 手机号
  String get mobile => this['mobile'] ?? '';
  // 昵称
  String get nickName => this['nickName'] ?? '';
  // 备注
  String get remark => this['remark'] ?? '';
  // 盐
  String get salt => this['salt'] ?? '';
  // 激活
  bool get isActive => this['isActive'] ?? false;

  // 头像文件地址
  String get avatorUrl => _avator?.url ?? '';
  // 用户类型
  UserType get userType => get<UserType>('userType');
  // 头像文件
  ParseFile get _avator => get<ParseFile>('avator');

}


// 问题类型
class ProblemType extends ParseObject implements ParseCloneable {

  ProblemType() : super(kTableName);
  ProblemType.clone() : this();
  
  @override clone(Map map) => ProblemType.clone().fromJson(map);

  static const String kTableName = 'ProblemType';
  // ID
  int get id => this['problemTypeId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 标题
  String get title => this['title'] ?? '';
  // 内容
  String get content => this['content'] ?? '';
  // 可用
  bool get isActive => this['isActive'] ?? false;

}

// 问题反馈记录
class ProblemFeedback extends ParseObject implements ParseCloneable {

  ProblemFeedback() : super(kTableName);
  ProblemFeedback.clone() : this();
  
  @override clone(Map map) => ProblemFeedback.clone().fromJson(map);

  static const String kTableName = 'ProblemFeedback';

  // ID
  int get id => this['feedBackId'] ?? 0;
  // 消息
  String get message => this['message'] ?? '';
  // 联系方式
  String get contactWay => this['contactWay'] ?? '';
  // 用户类型
  Users get fromUser => get<Users>('fromUser');
  // 产品
  Product get product => get<Product>('product');
  // 可用
  bool get isActive => this['isActive'] ?? false;

}


// 产品分类
class ProductCategory extends ParseObject implements ParseCloneable{

  ProductCategory() : super(kTableName);
  ProductCategory.clone() : this();
  
  @override clone(Map map) => ProductCategory.clone().fromJson(map);

  static const String kTableName = 'ProductCategory';

  // ID
  int get id => this['productCategoryId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 激活
  bool get isActive => this['isActive'] ?? false;

}

// 接入点类型
class AccessType extends ParseObject implements ParseCloneable {

  AccessType() : super(kTableName);
  AccessType.clone() : this();
  
  @override clone(Map map) => AccessType.clone().fromJson(map);

  static const String kTableName = 'AccessType';
  
  // ID
  int get id => this['accessTypeId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 备注
  String get remark => this['remark'] ?? '';
  // 激活
  bool get isActive => this['isActive'] ?? false;
  // 集控
  bool get isGrouped => this['isGrouped'] ?? false;

}

// 产品
class Product extends ParseObject implements ParseCloneable {

  Product() : super(kTableName);
  Product.clone() : this();
  
  @override clone(Map map) => Product.clone().fromJson(map);

  static const String kTableName = 'Product';
  // ID
  int get id => this['productId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 激活
  bool get isActive => this['isActive'] ?? false;
  // 新品
  bool get isNew => this['isNew'] ?? false;
  // 开启
  bool get isOpen => this['isOpen'] ?? true;
  // 封面图像地址
  String get coverUrl => _cover?.url ?? '';
  // 接入点
  AccessType get accessType => get<AccessType>('accessType');
  // 产品类型
  ProductCategory get productCategory => get<ProductCategory>('productCategory');
  // 封面文件
  ParseFile get _cover => get<ParseFile>('cover');

}

// 产品SKU
class ProductSKU extends ParseObject implements ParseCloneable {

  ProductSKU() : super(kTableName);
  ProductSKU.clone() : this();
  
  @override clone(Map map) => ProductSKU.clone().fromJson(map);

  static const String kTableName = 'ProductSKU';

  // ID
  int get id => this['productSkuId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 产品
  Product get product => get<Product>('product');
  // 激活
  bool get isActive => this['isActive'] ?? false;
  // 参数
  dynamic get skuParam => this['skuParam'];

}

// 用户方案

class UserScheme extends ParseObject implements ParseCloneable {

  UserScheme() : super(kTableName);
  UserScheme.clone() : this();
  
  @override clone(Map map) => UserScheme.clone().fromJson(map);

  static const String kTableName = 'UserScheme';

  // ID
  int get id => this['schemeId'] ?? 0;
  // 名称
  String get name => this['name'] ?? '';
  // 归属用户
  Users get user => get<Users>('user');
  // sku参数
  ProductSKU get sku => get<ProductSKU>('sku');
  // 激活
  bool get isActive => this['isActive'] ?? false;

}