part of leadlinkopenapi;

// 产品类接口
class APIProduct {

  // 获取所有品类列表
  static void getCategoryList({Function(List<ProductCategory> productCategoryList) onSucc, Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<ProductCategory>(ProductCategory())
      ..whereNotEqualTo('isActive', false);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<ProductCategory>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
    
  }

  // 根据选中品类获取右侧产品列表
  static void getProductListByCategoryId(int categoryId,{Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

        var queryCat = QueryBuilder<ProductCategory>(ProductCategory())
        ..whereEqualTo('productCategoryId', categoryId);

        var queryBuider = QueryBuilder<Product>(Product())
        ..whereNotEqualTo('isActive', false)
        ..whereMatchesQuery('productCategory',queryCat)
        ..includeObject(['productCategory','accessType']);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<Product>());

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }


  // 获取所有产品列表
  static void getProductListAll({Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..includeObject(['productCategory','accessType']);
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取新品产品接口
  static getNewProductList({Function(List<Product> productList) onSucc,Function(String) onFail}) async {
    
    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isNew', true)
      ..includeObject(['productCategory','accessType']);
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取产品详情
  static getProductDetailByProductId(int productId,{Function(Product product) onSucc,Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productId', productId);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      
      Product resProduct = resp.results.first;
      if(onSucc != null) onSucc(resProduct);

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }



  // 获取用户拥有的产品下的品类列表
  static getCategoryListByUser({Function(List<ProductCategory>) onSucc, Function(String) onFail}) async {
    APIScheme.getAllSchemeListByCurrentUser(
      onFail: onFail,
      onSucc: (schemes) {
        List<ProductCategory> datas = filterUniqueCategory(schemes);
        if (onSucc != null) onSucc(datas);
      },
    );
  }

  // 分类去重
  static List<ProductCategory> filterUniqueCategory(List<UserScheme> input) {

    List<ProductCategory> categoryList = [];
   
    if (input == null) return categoryList;
    if (input.length == 0) return categoryList;

    // 取 scheme并去重
     List<UserScheme> result = [];
    for (int i = 0; i < input.length; i++) {

      UserScheme scheme = input[i];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;

      final isRepeat = isFoundRepeat(catId, result);

      if (isRepeat == false) {
        result.add(scheme);
      }
    }


    for (int p = 0; p < result.length; p++) {
      UserScheme scheme= result[p];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      categoryList.add(category);
    }
    return categoryList;
  }

  // 判断重复
  static bool isFoundRepeat(int pickerCategoryId, List<UserScheme> tempList) {
    for (int k = 0; k < tempList.length; k++) {
      UserScheme scheme = tempList[k];
      ProductSKU sku = scheme.sku;
      Product product = sku.product;
      ProductCategory category= product.productCategory;
      int catId = category.id;
      if (pickerCategoryId.compareTo(catId) == 0) {
        return true;
      }
    }
    return false;
  } 
  






}